summaryrefslogtreecommitdiff
path: root/drivers
diff options
context:
space:
mode:
authorHanna Hawa <hannah@marvell.com>2017-08-25 17:24:31 +0300
committerKostya Porotchkin <kostap@marvell.com>2017-08-27 17:12:39 +0300
commit6745beea9c15872d3f86c89c66bd2f442d4c64cb (patch)
tree11789a1c0ed1771f2348978bc51e2d4ce22bf4c3 /drivers
parentf2e69c9b9d8309d4db4a6b4a7826821711234b4d (diff)
mvebu: io-win: add function to get the target ID of GCR
Part of AP810 preparation and driver changes, may some north bridge have different target IDs for the GCR. Change-Id: I06221baf00f2f69d40382e27d49fe166ab43de4e Signed-off-by: Hanna Hawa <hannah@marvell.com> Reviewed-on: http://vgitil04.il.marvell.com:8080/43402 Reviewed-by: Kostya Porotchkin <kostap@marvell.com> Tested-by: iSoC Platform CI <ykjenk@marvell.com>
Diffstat (limited to 'drivers')
-rw-r--r--drivers/marvell/io_win.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/marvell/io_win.c b/drivers/marvell/io_win.c
index c01bc129..a38d1079 100644
--- a/drivers/marvell/io_win.c
+++ b/drivers/marvell/io_win.c
@@ -168,8 +168,8 @@ int init_io_win(int ap_index)
return 0;
}
- /* set the default target id to PIDI */
- win_reg = PIDI_TID;
+ /* Get the default target id to set the GCR */
+ win_reg = marvell_get_io_win_gcr_target(ap_index);
mmio_write_32(IO_WIN_GCR_OFFSET, win_reg);
/* disable all IO windows */